//  Copyright (c) 2015 Razeware LLC. All rights reserved.

import UIKit

class CardNode: ASDisplayNode {
  // 1
  let imageNode: ASImageNode
  let titleTextNode: ASTextNode
  
  // 2
  init(card: Card) {
    imageNode = ASImageNode()
    titleTextNode = ASTextNode()
    super.init()
    setUpSubnodesWithCard(card)
    buildSubnodeHierarchy()
  }
  
  // 3
  func setUpSubnodesWithCard(card: Card) {
    // Set up image node
    imageNode.image = card.image
    // Set up title text node
    titleTextNode.attributedString = NSAttributedString.attributedStringForTitleText(card.name)
  }
  
  // 4
  func buildSubnodeHierarchy() {
    addSubnode(imageNode)
    addSubnode(titleTextNode)
  }
  
  override func calculateSizeThatFits(constrainedSize: CGSize) -> CGSize {
    // 1 Measure image node using the constrained size provided
    imageNode.measure(constrainedSize)
    
    // 2 Use image node's measured size as the card node size to constrain subnodes
    let cardSize = imageNode.calculatedSize
    
    // Measure the rest of the subnodes using this card's size as the constrained size
    titleTextNode.measure(cardSize)
    
    // 3 Return this card node's calculated size that fits within the constrained size provided
    return cardSize
  }
  
  override func layout() {
    imageNode.frame =
      CGRect(origin: CGPointZero, size: imageNode.calculatedSize).integerRect
    titleTextNode.frame =
      FrameCalculator.titleFrameForSize(titleTextNode.calculatedSize, containerFrame: imageNode.frame)
  }
}
